import React, { useMemo } from 'react';
import Helmet from 'next/head';
import { Layout } from '@component-controls/base-integration';
import { __rest } from 'tslib';
import Link from 'next/link';
import { getHomePath, ensureTrailingSlash, getRoutePath } from '@component-controls/core';
import { useStore, loadStore } from '@component-controls/store';
import { getIndexPage as getIndexPage$1, getHomePages, getDocPages } from '@component-controls/routes';

const NextLink = (_a) => {
    var { href = '', children } = _a, props = __rest(_a, ["href", "children"]);
    const store = useStore();
    const homePath = useMemo(() => getHomePath(store), [store]);
    const homePathParts = homePath === '/' ? 1 : homePath.split('/').length;
    if (href.startsWith('#')) {
        return (React.createElement("a", Object.assign({ href: href }, props), children));
    }
    const urlparts = href.split('/');
    const isHomePage = href === homePath;
    const isDocTypeHome = (!isHomePage && urlparts.length === 1 + homePathParts) ||
        (urlparts.length === 2 + homePathParts &&
            urlparts[1 + homePathParts] === '');
    const homePagePrefix = ensureTrailingSlash(homePath);
    const dynamicHref = isHomePage
        ? homePath
        : isDocTypeHome
            ? `${homePagePrefix}[doctype]`
            : `${homePagePrefix}[doctype]/[...docid]`;
    return (React.createElement(Link, { href: dynamicHref, as: `${href}` },
        React.createElement("a", Object.assign({}, props), children)));
};

const bundle = require('./component-controls');
const store = loadStore(bundle, true);

const NextLayout = props => {
    let head;
    if (typeof process.env.NEXT_PUBLIC_CC_CSS === 'string') {
        head = (React.createElement(Helmet, null,
            React.createElement("style", { key: "controls-styles" }, JSON.parse(process.env.NEXT_PUBLIC_CC_CSS))));
    }
    return (React.createElement(React.Fragment, null,
        head,
        React.createElement(Layout, Object.assign({}, props, { store: store, Helmet: Helmet, Link: NextLink }))));
};

const getIndexPage = () => getIndexPage$1(store);
const getHomePagesPaths = () => {
    const pages = getHomePages(store);
    return pages.map(page => page.path);
};
const getDocHomePage = (path) => {
    const pages = getHomePages(store);
    const resolvedPath = getRoutePath(store, path);
    const page = pages.find(page => page.path === resolvedPath);
    return page || { path };
};
const getDocPagesPaths = () => {
    const pages = getDocPages(store);
    return pages.map(page => page.path);
};
const getDocPage = (docType, docId) => {
    const homePath = getHomePath(store);
    const path = `${ensureTrailingSlash(homePath)}${docType}/${docId.join('/')}`;
    const pages = getDocPages(store);
    const page = pages.find(page => page.path === path);
    return page || { path };
};

export { NextLayout, getDocHomePage, getDocPage, getDocPagesPaths, getHomePagesPaths, getIndexPage };
