'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var Helmet = require('next/head');
var baseIntegration = require('@component-controls/base-integration');
var tslib = require('tslib');
var Link = require('next/link');
var core = require('@component-controls/core');
var store$1 = require('@component-controls/store');
var routes = require('@component-controls/routes');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
var Helmet__default = /*#__PURE__*/_interopDefaultLegacy(Helmet);
var Link__default = /*#__PURE__*/_interopDefaultLegacy(Link);

const NextLink = (_a) => {
    var { href = '', children } = _a, props = tslib.__rest(_a, ["href", "children"]);
    const store = store$1.useStore();
    const homePath = React.useMemo(() => core.getHomePath(store), [store]);
    const homePathParts = homePath === '/' ? 1 : homePath.split('/').length;
    if (href.startsWith('#')) {
        return (React__default["default"].createElement("a", Object.assign({ href: href }, props), children));
    }
    const urlparts = href.split('/');
    const isHomePage = href === homePath;
    const isDocTypeHome = (!isHomePage && urlparts.length === 1 + homePathParts) ||
        (urlparts.length === 2 + homePathParts &&
            urlparts[1 + homePathParts] === '');
    const homePagePrefix = core.ensureTrailingSlash(homePath);
    const dynamicHref = isHomePage
        ? homePath
        : isDocTypeHome
            ? `${homePagePrefix}[doctype]`
            : `${homePagePrefix}[doctype]/[...docid]`;
    return (React__default["default"].createElement(Link__default["default"], { href: dynamicHref, as: `${href}` },
        React__default["default"].createElement("a", Object.assign({}, props), children)));
};

const bundle = require('./component-controls');
const store = store$1.loadStore(bundle, true);

const NextLayout = props => {
    let head;
    if (typeof process.env.NEXT_PUBLIC_CC_CSS === 'string') {
        head = (React__default["default"].createElement(Helmet__default["default"], null,
            React__default["default"].createElement("style", { key: "controls-styles" }, JSON.parse(process.env.NEXT_PUBLIC_CC_CSS))));
    }
    return (React__default["default"].createElement(React__default["default"].Fragment, null,
        head,
        React__default["default"].createElement(baseIntegration.Layout, Object.assign({}, props, { store: store, Helmet: Helmet__default["default"], Link: NextLink }))));
};

const getIndexPage = () => routes.getIndexPage(store);
const getHomePagesPaths = () => {
    const pages = routes.getHomePages(store);
    return pages.map(page => page.path);
};
const getDocHomePage = (path) => {
    const pages = routes.getHomePages(store);
    const resolvedPath = core.getRoutePath(store, path);
    const page = pages.find(page => page.path === resolvedPath);
    return page || { path };
};
const getDocPagesPaths = () => {
    const pages = routes.getDocPages(store);
    return pages.map(page => page.path);
};
const getDocPage = (docType, docId) => {
    const homePath = core.getHomePath(store);
    const path = `${core.ensureTrailingSlash(homePath)}${docType}/${docId.join('/')}`;
    const pages = routes.getDocPages(store);
    const page = pages.find(page => page.path === path);
    return page || { path };
};

exports.NextLayout = NextLayout;
exports.getDocHomePage = getDocHomePage;
exports.getDocPage = getDocPage;
exports.getDocPagesPaths = getDocPagesPaths;
exports.getHomePagesPaths = getHomePagesPaths;
exports.getIndexPage = getIndexPage;
